==> payara-embedded-web-4.1.2.172-sources.jar: fish/payara/nucleus/hazelcast/contextproxy/EntryProcessorProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) [2016-2017] Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.nucleus.hazelcast.contextproxy;

import org.glassfish.internal.api.JavaEEContextUtil;
import org.glassfish.internal.api.JavaEEContextUtil.Context;
import javax.cache.processor.EntryProcessor;
import javax.cache.processor.EntryProcessorException;
import javax.cache.processor.MutableEntry;
import lombok.RequiredArgsConstructor;

/**
 * push Java EE environment before invoking delegate
 *
 * @author lprimak
 * @param <K>
 * @param <V>
 * @param <T>
 */
@RequiredArgsConstructor
public class EntryProcessorProxy<K, V, T> implements EntryProcessor<K, V, T>{
    @Override
    public T process(MutableEntry<K, V> me, Object... os) throws EntryProcessorException {
        Context ctx = null;
        try {
            ctx = ctxUtil.pushContext();
            return delegate.process(me, os);
        }
        finally {
            ctxUtil.popContext(ctx);
        }
    }

    private final EntryProcessor<K, V, T> delegate;
    private final JavaEEContextUtil ctxUtil;
}

==> payara-embedded-web-5.2021.2-sources.jar: fish/payara/nucleus/hazelcast/contextproxy/EntryProcessorProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) [2016-2019] Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.nucleus.hazelcast.contextproxy;

import java.io.Serializable;
import org.glassfish.internal.api.JavaEEContextUtil;
import org.glassfish.internal.api.JavaEEContextUtil.Context;
import javax.cache.processor.EntryProcessor;
import javax.cache.processor.EntryProcessorException;
import javax.cache.processor.MutableEntry;

/**
 * push Java EE environment before invoking delegate
 *
 * @author lprimak
 * @param <K>
 * @param <V>
 * @param <T>
 */
public class EntryProcessorProxy<K, V, T> implements EntryProcessor<K, V, T>, Serializable {
    @Override
    public T process(MutableEntry<K, V> me, Object... os) throws EntryProcessorException {
        try (Context ctx = ctxUtilInst.pushContext()) {
            return delegate.process(me, os);
        }
    }

    public EntryProcessorProxy(EntryProcessor<K, V, T> delegate, JavaEEContextUtil.Instance ctxUtilInst) {
        this.delegate = delegate;
        this.ctxUtilInst = ctxUtilInst;
    }

    private final EntryProcessor<K, V, T> delegate;
    private final JavaEEContextUtil.Instance ctxUtilInst;
    private static final long serialVersionUID = 1L;
}
